Package 'ZarrDataFrame'

Title: Bioconductor-friendly Bindings for Zarr
Description: Implements bindings for zarr store that are compatible with Bioconductor S4 data structures, namely the DataFrame and DelayedArray. This allows Zarr-backed data to be easily used as data frames with arbitrary sets of columns
Authors: Artur Manukyan [aut, cre]
Maintainer: Artur Manukyan <[email protected]>
License: MIT + file LICENSE
Version: 0.0.0
Built: 2026-04-02 09:17:13 UTC
Source: https://github.com/Artur-man/ZarrDataFrame

Help Index


open_zarr

Description

open zarr store

Usage

open_zarr(dir, name)

Arguments

dir

the location of zarr store

name

name of the zarr store


Column of an Zarr-based data frame

Description

Represent a column of a Zarr-based data frame as a 1-dimensional DelayedArray. This allows us to use Zarr-backed data inside DataFrames without loading them into memory.

Usage

ZarrColumnSeed(path, name, column, type = NULL, length = NULL)

ZarrColumnVector(x, ...)

Arguments

path

String containing a path to a Zarr-based data frame.

name

String containing the Zarr group of the Zarr file.

column

String containing the name of the column inside the Zarr file.

type

String specifying the type of the data. If NULL, this is determined by inspecting the file. Users may specify this to avoid a look-up, or to coerce the output into a different type.

length

Integer containing the number of rows. If NULL, this is determined by inspecting the file. This should only be supplied for efficiency purposes, to avoid a file look-up on construction.

x

Either a string containing the path to an Zarr-based data frame file (to be used as path), or an existing ZarrColumnSeed object.

...

Further arguments to be passed to the ZarrColumnSeed constructor.

Value

For ZarrColumnSeed, a ZarrColumnSeed is returned, obviously.

For ZarrColumnVector, a ZarrColumnVector is returned.

Author(s)

Artür Manukyan


zarrcreateGroup

Description

get information of an ImgArray object

Usage

zarrcreateGroup(store, name)

Arguments

store

the location of (zarr) store

name

name of the group


Zarr-backed DataFrame

Description

Create a Zarr-backed DataFrame, where the data are kept on disk until requested.

Usage

ZarrDataFrame(tab, name, columns = NULL, nrows = NULL)

Arguments

tab

A set of ZarrArrays that are the columns of a data frame.

name

String containing the Zarr group of the Zarr file.

columns

Character vector containing the names of columns in a Zarr-based data frame. If NULL, this is determined from path.

nrows

Integer scalar specifying the number of rows in a Zarr-based data frame. If NULL, this is determined from path.

Value

A ZarrDataFrame where each column is a ZarrColumnVector.

Author(s)

Artür Manukyan