| Title: | Bioconductor-friendly Bindings for Zarr |
|---|---|
| Description: | Implements bindings for zarr store that are compatible with Bioconductor S4 data structures, namely the DataFrame and DelayedArray. This allows Zarr-backed data to be easily used as data frames with arbitrary sets of columns |
| Authors: | Artur Manukyan [aut, cre] |
| Maintainer: | Artur Manukyan <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0 |
| Built: | 2026-05-27 06:20:18 UTC |
| Source: | https://github.com/BIMSBbioinfo/ZarrDataFrame |
open zarr store
open_zarr(dir, name)open_zarr(dir, name)
dir |
the location of zarr store |
name |
name of the zarr store |
Represent a column of a Zarr-based data frame as a 1-dimensional DelayedArray. This allows us to use Zarr-backed data inside DataFrames without loading them into memory.
ZarrColumnSeed(path, name, column, type = NULL, length = NULL) ZarrColumnVector(x, ...)ZarrColumnSeed(path, name, column, type = NULL, length = NULL) ZarrColumnVector(x, ...)
path |
String containing a path to a Zarr-based data frame. |
name |
String containing the Zarr group of the Zarr file. |
column |
String containing the name of the column inside the Zarr file. |
type |
String specifying the type of the data.
If |
length |
Integer containing the number of rows.
If |
x |
Either a string containing the path to an Zarr-based data frame file (to be used as |
... |
Further arguments to be passed to the |
For ZarrColumnSeed, a ZarrColumnSeed is returned, obviously.
For ZarrColumnVector, a ZarrColumnVector is returned.
Artür Manukyan
get information of an ImgArray object
zarrcreateGroup(store, name)zarrcreateGroup(store, name)
store |
the location of (zarr) store |
name |
name of the group |
Create a Zarr-backed DataFrame, where the data are kept on disk until requested.
ZarrDataFrame(tab, name, columns = NULL, nrows = NULL)ZarrDataFrame(tab, name, columns = NULL, nrows = NULL)
tab |
A set of ZarrArrays that are the columns of a data frame. |
name |
String containing the Zarr group of the Zarr file. |
columns |
Character vector containing the names of columns in a Zarr-based data frame.
If |
nrows |
Integer scalar specifying the number of rows in a Zarr-based data frame.
If |
A ZarrDataFrame where each column is a ZarrColumnVector.
Artür Manukyan